@@ -1,23 +1,23 @@
-/* 
+/*
  * Copyright (C) 2000 Rich Wareham <richwareham@users.sourceforge.net>
- * 
+ *
  * This file is part of libdvdnav, a DVD navigation library.
- * 
+ *
  * libdvdnav is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * libdvdnav is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: settings.c 900 2007-04-24 23:06:22Z nicodvb $
+ * $Id: settings.c 1135 2008-09-06 21:55:51Z rathann $
  *
  */
 
@@ -30,12 +30,11 @@
 #include <string.h>
 #include <sys/time.h>
 #include "dvd_types.h"
-#include "nav_types.h"
-#include "ifo_types.h"
+#include <dvdread/nav_types.h>
+#include <dvdread/ifo_types.h>
 #include "remap.h"
 #include "vm/decoder.h"
 #include "vm/vm.h"
-#include "vm/vmcmd.h"
 #include "dvdnav.h"
 #include "dvdnav_internal.h"
 
@@ -68,7 +67,7 @@ static dvdnav_status_t set_language_register(dvdnav_t *this, char *code, int reg
     printerr("Passed illegal language code.");
     return DVDNAV_STATUS_ERR;
   }
-  
+
   pthread_mutex_lock(&this->vm_lock);
   this->vm->state.registers.SPRM[reg] = (code[0] << 8) | code[1];
   pthread_mutex_unlock(&this->vm_lock);
